<?php
/* vim: set expandtab tabstop=4 softtabstop=4 shiftwidth=4:
  Codificación: UTF-8
  +----------------------------------------------------------------------+
  | Elastix version 2.4.0-1                                              |
  | http://www.elastix.org                                               |
  +----------------------------------------------------------------------+
  | Copyright (c) 2006 Palosanto Solutions S. A.                         |
  +----------------------------------------------------------------------+
  | Cdla. Nueva Kennedy Calle E 222 y 9na. Este                          |
  | Telfs. 2283-268, 2294-440, 2284-356                                  |
  | Guayaquil - Ecuador                                                  |
  | http://www.palosanto.com                                             |
  +----------------------------------------------------------------------+
  | The contents of this file are subject to the General Public License  |
  | (GPL) Version 2 (the "License"); you may not use this file except in |
  | compliance with the License. You may obtain a copy of the License at |
  | http://www.opensource.org/licenses/gpl-license.php                   |
  |                                                                      |
  | Software distributed under the License is distributed on an "AS IS"  |
  | basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See  |
  | the License for the specific language governing rights and           |
  | limitations under the License.                                       |
  +----------------------------------------------------------------------+
  | The Original Code is: Elastix Open Source.                           |
  | The Initial Developer of the Original Code is PaloSanto Solutions    |
  +----------------------------------------------------------------------+
  $Id: paloSantoFail2Ban.class.php,v 1.1 2013-06-10 07:10:30 Nikita Rukavkov admin@voip-lab.ru Exp $ */

include_once("libs/paloSantoDB.class.php");
include_once("libs/paloSantoConfig.class.php");

/* Clase que implementa DHCP Server */
class PaloSantoFail2Ban
{
    var $errMsg;
    var $pConfig;
    var $filename_cfg;

    function PaloSantoFail2Ban()
    {
	$this->pConfig = new paloConfig("modules/anti_hacker/configs","settings.conf"," = ","\s*=\s*");
	$this->filename_cfg = "modules/anti_hacker/configs/settings.conf";
	if(!file_exists($this->filename_cfg)) touch($this->filename_cfg);
    }
    
    function load_fail2ban_table($filter_Jail,$filter_IP)
    {
	$ret = split("\n", `sudo /usr/sbin/elastix-helper fail2ban --dumpiptables`);

	$rTable=array();

	foreach($ret as $n => $rstr) {
    	    $r = preg_split("/[\s]+/", $rstr);
    	    if(isset($r[3]))
    	    if(preg_match('/^(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]\d|\d)(?:[.](?:25[0-5]|2[0-4]\d|1\d\d|[1-9]\d|\d)){3}$/',$r[3])) { 
    		$r[1]=str_replace('fail2ban-','',$r[1]);
		$arrTmp[0] = "<input type='checkbox' name='ip[]' value='$r[3],$r[1]' />";
		$need_add = FALSE;
    		if($filter_Jail != '' && $filter_IP != '')
    		    $need_add = ($filter_Jail==$r[1] && $filter_IP==$r[3]) ? TRUE : FALSE;
		else if ($filter_Jail != '')
    		    $need_add = ($filter_Jail==$r[1]) ? TRUE : FALSE;
    		else if ($filter_IP != '')
    		    $need_add = ($filter_IP==$r[3]) ? TRUE : FALSE;
    		else $need_add = TRUE;
		    
		if($need_add) $rTable[] = array($arrTmp[0],$r[3],$r[1]);
	    }    
	}
	return $rTable;
    }


    function getConfigurationFail2Ban() 
    {
        global $arrLang;

    }

    function getStatusServiceFail2Ban()
    {
        $output = $ret = NULL;
        exec('/sbin/service fail2ban status > /dev/null 2>&1', $output, $ret);
        return ($ret == 0) ? 'active' : 'desactive';
    }

    function startServiceFail2Ban()
    {
        $this->errMsg = '';
        if(count($this->pConfig->leer_configuracion())>0)
        {
    	    $sComando = '/usr/bin/elastix-helper fail2ban --start 2>&1';
    	    $output = $ret = NULL;
    	    exec($sComando, $output, $ret);
    	    if ($ret != 0) {
        	$this->errMsg = implode('', $output);
        	return FALSE;
    	    }
    	    return TRUE;
    	}
    	else
    	{
    	    $this->errMsg = 'First save settings';
    	    return FALSE;
    	}
    }

    function stopServiceFail2Ban()
    {
        $this->errMsg = '';
        $sComando = 'sudo /usr/sbin/elastix-helper fail2ban --stop 2>&1';
        $output = $ret = NULL;
        exec($sComando, $output, $ret);
        if ($ret != 0) {
            $this->errMsg = implode('', $output);
            return FALSE;
        }
        return TRUE;
    }

    function updateFileConfFail2Ban($arrValues)
    {

	global $arrLang;
        $this->errMsg = '';
        $arrValues['bantime']*=3600;
        if ( is_writeable($this->filename_cfg) )
        {
            $sComando = '/usr/bin/elastix-helper fail2ban --config'.
                    ' --mail '.escapeshellcmd($arrValues['target']).
                    ' --count '.escapeshellcmd($arrValues['count']).
                    ' --bantime '.escapeshellcmd($arrValues['bantime']).
                    ($arrValues['exceptions'] != '' ? ' --exceptions '.escapeshellcmd($arrValues['exceptions']) : '').
                    ($arrValues['websecure'] == 'on' ? ' --web' : '').
                    ($arrValues['sshsecure'] == 'on' ? ' --ssh' : '').
                    ($arrValues['vsftpdsecure'] == 'on' ? ' --vsftpd' : '').
                    ($arrValues['asterisksecure'] == 'on' ? ' --asterisk' : '').
                    ' 2>&1';
            $output = $ret = NULL;
            exec($sComando, $output, $ret);
            if ($ret != 0) {
                $this->errMsg = implode('', $output);
		return FALSE;
            }
            else
            {
                $this->pConfig->escribir_configuracion($arrValues);
                return TRUE;
            }
        }
        else
        {
            $this->errMsg = $arrLang["Please check permissions"];
            return FALSE;
        }
    }
    
    function removeFromIptables($ip)
    {
	foreach($ip as $comb)
	{
	    $arrTmp = explode(",",$comb);
	    $ip = $arrTmp[0];
	    $table = 'fail2ban-'.$arrTmp[1];
	    `sudo /usr/sbin/elastix-helper fail2ban --removefromiptables --table $table --ip $ip`;
	}
    }
    function loadSettings($param=FALSE)
    {
        $settings = $this->pConfig->leer_configuracion($param);
	$arrValues['bantime'] = $this->pConfig->privado_get_valor($settings,"bantime")/3600;
	$arrValues['count'] = $this->pConfig->privado_get_valor($settings,"count");
        $arrValues['target'] =  $this->pConfig->privado_get_valor($settings,"target");
	$arrValues['exceptions'] = $this->pConfig->privado_get_valor($settings,"exceptions");
	$arrValues['asterisksecure'] = $this->pConfig->privado_get_valor($settings,"asterisksecure");
        $arrValues['websecure'] = $this->pConfig->privado_get_valor($settings,"websecure");
	$arrValues['sshsecure'] = $this->pConfig->privado_get_valor($settings,"sshsecure");
	$arrValues['vsftpdsecure'] = $this->pConfig->privado_get_valor($settings,"vsftpdsecure");
	return $arrValues;
    }
    function checkInstall($namePackage)
    {
    	global $arrLang;
    	$this->errMsg = '';
	exec("rpm -q $namePackage",$respuesta,$retorno);
	if($retorno == 0){
	    return TRUE;
	}
	else{
	    return FALSE;
	}
    }
}
?>
